# cog2 a modified version of cog

Use this command to start the virtual environment
```commandline
poetry shell
```
install to current the program virtual environment
```commandline
peotry install
```

build the whl
```commandline
poetry build
```

PyPi token config
```commandline
poetry config pypi-token.pypi pypi-wubalubadubdub-deadbeef1234
```

build and publish
```commandline
poetry publish --build
```

install from pip
```commandline
pip install --user cog2
```
